@@ -15,6 +15,10 @@ class TestDBResource(object):
         cmd = "SELECT * FROM test_results WHERE test_key='{}'".format(key)
         self.sql.cursor.execute(cmd)
         result = self.sql.cursor.fetchone()
+        if result is not None:
+            log = result[7][-10000:]   # reduce log size : Liangmin requirement
+            result = list(result)
+            result[7] = log
         return result
 
     def get_latest_tests_from_db(self, ip, numbers):
@@ -28,17 +32,21 @@ class TestDBResource(object):
         results = self.get_latest_tests_from_db(ip, numbers)
         for item in results:
             duration = (item[9]-item[8]).total_seconds() if None not in [item[8],item[9]] else 0
+            log = item[7]
+            if (log is not None) and (type(log)==str):
+                log = log[-10000:]
             test = {
                 "name": item[2],
                 "state": item[4],
                 "start_time": item[8],
                 "end_time": item[9],
-                "duration": duration}
+                "duration": duration,
+                "log": log}
             tests.append(test)
         return tests
 
-#
-# if __name__ == '__main__':
-#     DB = TestDBResource()
-#     tests1 = DB.get_tests_by_ip("172.29.131.80", 100)
-#     pass
+
+if __name__ == '__main__':
+    DB = TestDBResource()
+    tests1 = DB.get_result("9cd1r0nbc2")
+    pass
